==> dde-dock_5.4.10.orig.tar.xz: dde-dock-5.4.10/translations/dde-dock_es.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="es" version="2.1">
<context>
    <name>AbstractPluginsController</name>
    <message>
        <source>The plugin %1 is not compatible with the system.</source>
        <translation>El complemento %1 no es compatible con el sistema.</translation>
    </message>
</context>
<context>
    <name>AppDragWidget</name>
    <message>
        <source>Remove</source>
        <translation>Quitar</translation>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation>Ajustes de Bluetooth</translation>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation>Desactivar</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>Activar</translation>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation>Ajustes de Bluetooth</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 conectado</translation>
    </message>
    <message>
        <source>Connecting...</source>
        <translation>Conectando...</translation>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>Apagado</translation>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>Añadir distribución de teclado</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>Fecha y hora</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>Formato de 12 horas</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>Formato de 24 horas</translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>Ajustes de fecha y hora</translation>
    </message>
</context>
<context>
    <name>DeviceItem</name>
    <message>
        <source>Enable network</source>
        <translation>Habilitar red</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Deshabilitar red</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Ajustes de red</translation>
    </message>
</context>
<context>
    <name>DialogManager</name>
    <message>
        <source>Are you sure you want to empty %1 items?</source>
        <translation>¿Está seguro de vaciar %1 elementos?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Borrar</translation>
    </message>
    <message>
        <source>This action cannot be restored</source>
        <translation>Esta acción no se puede deshacer</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown device</source>
        <translation>Dispositivo desconocido</translation>
    </message>
    <message>
        <source>Unknown volume</source>
        <translation>Volumen desconocido</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>Disco</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Abrir</translation>
    </message>
    <message>
        <source>Unmount all</source>
        <translation>Desmontar todo</translation>
    </message>
</context>
<context>
    <name>LauncherItem</name>
    <message>
        <source>Launcher</source>
        <translation>Lanzador</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Exit Safe Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Dock - Safe Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The Dock is in safe mode, please exit to show it properly</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Fashion Mode</source>
        <translation>Modo elegante</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>Modo eficiente</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Arriba</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Abajo</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Izquierda</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Derecha</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>Mantener visible</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>Mantener oculto</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>Ocultado inteligente</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Modo</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Ubicación</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Estado</translation>
    </message>
    <message>
        <source>Plugins</source>
        <translation>Complementos</translation>
    </message>
</context>
<context>
    <name>MultitaskingPlugin</name>
    <message>
        <source>Multitasking View</source>
        <translation>Vista multitarea</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Desanclar</translation>
    </message>
</context>
<context>
    <name>NetworkItem</name>
    <message>
        <source>Disable wired connection</source>
        <translation>Deshabilitar conexión cableada</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>Habilitar conexión cableada</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>Deshabilitar conexión inalámbrica</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>Habilitar conexión inalámbrica</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Deshabilitar red</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>Habilitar red</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Ajustes de red</translation>
    </message>
    <message>
        <source>Device disabled</source>
        <translation>Dispositivo deshabilitado</translation>
    </message>
    <message>
        <source>Wireless connection: %1</source>
        <translation>Conexión inalámbrica: %1</translation>
    </message>
    <message>
        <source>Wired connection: %1</source>
        <translation>Conexión cableada: %1</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>No conectado</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Conectando</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Conectado pero sin acceso a internet</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Cable de red desconectado</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Red inalámbrica</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Red cableada</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation>Conexión fallida</translation>
    </message>
</context>
<context>
    <name>NetworkPlugin</name>
    <message>
        <source>Network</source>
        <translation>Red</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Red cableada</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Red cableada %1</translation>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation>Teclado en pantalla</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Ajustes</translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power</source>
        <translation>Energía</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Ajustes de energía</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>Capacidad %1, %2 min restante</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>Capacidad %1, %2 h %3 min restante</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>Cargando %1, %2 min para completarse</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>Cargando %1, %2 h %3 min para completarse</translation>
    </message>
    <message>
        <source>Charged</source>
        <translation>Cargada</translation>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation>Capacidad %1</translation>
    </message>
    <message>
        <source>Charging %1</source>
        <translation>Cargando %1</translation>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation>Capacidad %1 ....</translation>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation>Capacidad% 1, completamente cargada</translation>
    </message>
</context>
<context>
    <name>ShowDesktopPlugin</name>
    <message>
        <source>Show Desktop</source>
        <translation>Mostrar escritorio</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Desanclar</translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Power</source>
        <translation>Apagar</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>Apagar</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Suspender</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Hibernar</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Bloquear</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Cerrar sesión</translation>
    </message>
    <message>
        <source>Switch account</source>
        <translation>Cambiar cuenta</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Ajustes de energía</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Reiniciar</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Device</source>
        <translation>Dispositivo</translation>
    </message>
</context>
<context>
    <name>SoundItem</name>
    <message>
        <source>Unmute</source>
        <translation>Activar sonido</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Silenciar</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>Ajustes de sonido</translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation>Volumen %1</translation>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>Sonido</translation>
    </message>
</context>
<context>
    <name>TrashPlugin</name>
    <message>
        <source>Trash</source>
        <translation>Papelera</translation>
    </message>
    <message>
        <source>Trash - %1 file</source>
        <translation>Papelera - %1 archivo</translation>
    </message>
    <message>
        <source>Trash - %1 files</source>
        <translation>Papelera - %1 archivos</translation>
    </message>
</context>
<context>
    <name>TrashWidget</name>
    <message>
        <source>Open</source>
        <translation>Abrir</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>Vaciar</translation>
    </message>
</context>
<context>
    <name>TrayPlugin</name>
    <message>
        <source>System Tray</source>
        <translation>Bandeja de sistema</translation>
    </message>
</context>
<context>
    <name>WirelessList</name>
    <message>
        <source>Wireless Network</source>
        <translation>Red inalámbrica</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Red inalámbrica %1</translation>
    </message>
</context>
</TS>

==> dde-dock_5.5.53.orig.tar.xz: dde-dock-5.5.53/translations/dde-dock_es.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="es">
<context>
    <name>AbstractPluginsController</name>
    <message>
        <source>The plugin %1 is not compatible with the system.</source>
        <translation>El complemento %1 no es compatible con el sistema.</translation>
    </message>
</context>
<context>
    <name>AirplaneModeApplet</name>
    <message>
        <source>Airplane Mode</source>
        <translation>Modo avión</translation>
    </message>
</context>
<context>
    <name>AirplaneModeItem</name>
    <message>
        <source>Airplane mode enabled</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Turn off</source>
        <translation>Desactivar</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>Activar</translation>
    </message>
    <message>
        <source>Airplane Mode settings</source>
        <translation>Ajustes de modo avión</translation>
    </message>
    <message>
        <source>Airplane mode disabled</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AirplaneModePlugin</name>
    <message>
        <source>Airplane Mode</source>
        <translation>Modo avión</translation>
    </message>
</context>
<context>
    <name>AppDragWidget</name>
    <message>
        <source>Remove</source>
        <translation>Quitar</translation>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation>Ajustes de Bluetooth</translation>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation>Desactivar</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>Activar</translation>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation>Ajustes de Bluetooth</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 conectado</translation>
    </message>
    <message>
        <source>Connecting...</source>
        <translation>Conectando...</translation>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>Apagado</translation>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>Añadir distribución de teclado</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>Fecha y hora</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>Formato de 12 horas</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>Formato de 24 horas</translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>Ajustes de fecha y hora</translation>
    </message>
</context>
<context>
    <name>DialogManager</name>
    <message>
        <source>Are you sure you want to empty %1 items?</source>
        <translation>¿Está seguro de vaciar %1 elementos?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Borrar</translation>
    </message>
    <message>
        <source>This action cannot be restored</source>
        <translation>Esta acción no se puede deshacer</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown device</source>
        <translation>Dispositivo desconocido</translation>
    </message>
    <message>
        <source>Unknown volume</source>
        <translation>Volumen desconocido</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>Disco</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Abrir</translation>
    </message>
    <message>
        <source>Unmount all</source>
        <translation>Desmontar todo</translation>
    </message>
</context>
<context>
    <name>LauncherItem</name>
    <message>
        <source>Launcher</source>
        <translation>Lanzador</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Exit Safe Mode</source>
        <translation>Salir del modo seguro</translation>
    </message>
    <message>
        <source>Dock - Safe Mode</source>
        <translation>Muelle - Modo seguro</translation>
    </message>
    <message>
        <source>The Dock is in safe mode, please exit to show it properly</source>
        <translation>El muelle está en modo seguro, por favor salga para verlo correctamente</translation>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Fashion Mode</source>
        <translation>Modo elegante</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>Modo eficiente</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Arriba</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Abajo</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Izquierda</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Derecha</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>Mantener visible</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>Mantener oculto</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>Ocultado inteligente</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Modo</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Ubicación</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Estado</translation>
    </message>
    <message>
        <source>Dock settings</source>
        <translation>Ajustes del dock</translation>
    </message>
</context>
<context>
    <name>ModuleWidget</name>
    <message>
        <source>Size</source>
        <translation>Tamaño</translation>
    </message>
    <message>
        <source>Multiple Displays</source>
        <translation>Múltiples pantallas</translation>
    </message>
    <message>
        <source>Plugin Area</source>
        <translation>Área de complementos</translation>
    </message>
    <message>
        <source>Select which icons appear in the Dock</source>
        <translation>Seleccionar los iconos que aparecen en el Dock</translation>
    </message>
    <message>
        <source>Fashion mode</source>
        <translation>Modo elegante</translation>
    </message>
    <message>
        <source>Efficient mode</source>
        <translation>Modo eficiente</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>modo</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Arriba</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Abajo</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Izquierda</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Derecha</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Ubicación</translation>
    </message>
    <message>
        <source>Keep shown</source>
        <translation>Mantener visible</translation>
    </message>
    <message>
        <source>Keep hidden</source>
        <translation>Mantener oculto</translation>
    </message>
    <message>
        <source>Smart hide</source>
        <translation>Ocultar inteligentemente</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Estado</translation>
    </message>
    <message>
        <source>Small</source>
        <translation>Pequeña</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>Grandes</translation>
    </message>
    <message>
        <source>Show Dock</source>
        <translation>Mostrar el muelle</translation>
    </message>
    <message>
        <source>On screen where the cursor is</source>
        <translation>En la pantalla donde está el cursor</translation>
    </message>
    <message>
        <source>Only on main screen</source>
        <translation>Solo en la pantalla principal</translation>
    </message>
</context>
<context>
    <name>MultitaskingPlugin</name>
    <message>
        <source>Multitasking View</source>
        <translation>Vista multitarea</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Desanclar</translation>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation>Teclado en pantalla</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Ajustes</translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power</source>
        <translation>Energía</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Ajustes de energía</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>Capacidad %1, %2 min restante</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>Capacidad %1, %2 h %3 min restante</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>Cargando %1, %2 min para completarse</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>Cargando %1, %2 h %3 min para completarse</translation>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation>Capacidad %1</translation>
    </message>
    <message>
        <source>Charging %1</source>
        <translation>Cargando %1</translation>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation>Capacidad %1 ....</translation>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation>Capacidad %1, completamente cargada</translation>
    </message>
</context>
<context>
    <name>SettingsModule</name>
    <message>
        <source>Dock</source>
        <translation>Dock</translation>
        <extra-contents_path>/personalization/Dock</extra-contents_path>
    </message>
</context>
<context>
    <name>ShowDesktopPlugin</name>
    <message>
        <source>Show Desktop</source>
        <translation>Mostrar escritorio</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Desanclar</translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Power</source>
        <translation>Apagar</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>Apagar</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Suspender</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Hibernar</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Bloquear</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Cerrar sesión</translation>
    </message>
    <message>
        <source>Switch account</source>
        <translation>Cambiar cuenta</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Ajustes de energía</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Reiniciar</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Device</source>
        <translation>Dispositivo</translation>
    </message>
</context>
<context>
    <name>SoundItem</name>
    <message>
        <source>Unmute</source>
        <translation>Activar sonido</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Silenciar</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>Ajustes de sonido</translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation>Volumen %1</translation>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>Sonido</translation>
    </message>
</context>
<context>
    <name>TrashPlugin</name>
    <message>
        <source>Trash</source>
        <translation>Papelera</translation>
    </message>
    <message>
        <source>Trash - %1 file</source>
        <translation>Papelera - %1 archivo</translation>
    </message>
    <message>
        <source>Trash - %1 files</source>
        <translation>Papelera - %1 archivos</translation>
    </message>
    <message>
        <source>Move to Trash</source>
        <translation>Mover a la Papelera</translation>
    </message>
</context>
<context>
    <name>TrashWidget</name>
    <message>
        <source>Open</source>
        <translation>Abrir</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>Vaciar</translation>
    </message>
</context>
</TS>
